@@ -74,9 +74,11 @@ class Converter:
     def link_to_link_post_model(
             url: str,
             title: str,
-            url_type: LinkType,
+            url_type,
             description: str):
         if url_type:
+            if type(url_type) is str:
+                url_type = LinkType(value=url_type)
             return LinkPostModel(
                 url,
                 title=title,
@@ -94,9 +96,11 @@ class Converter:
     def link_to_link_put_model(
             url: str,
             title: str,
-            url_type: LinkType,
+            url_type,
             description: str):
         if url_type:
+            if type(url_type) is str:
+                url_type = LinkType(value=url_type)
             return LinkPutModel(
                 url,
                 title=title,
